##  Making Fact Sheet Fields Available as Filter Options
If certain fields on relations are not available in the filter options, it means they are not configured to be shown in filters. You can configure these fields by enabling the Show in filters toggle in the fact sheet configuration. For details, see [Showing Fields in Filters](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_filters).
![Configuring Fields to be Shown in Filters](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274bc9e17a441014b6698ed66ac88ced_LowRes.png)
Configuring Fields to be Shown in Filters
